==> hoteldruid-mod-sv_2.1.2-1.tar.gz: sv/modifica_contratto.php <==
<?php

switch ($messaggio) {

case "Torna indietro":  			$messaggio = "Bak&aring;t"; break;
case "Modifica il documento":  			$messaggio = "&Auml;ndra dokument"; break;
case "Salva le modifiche":  			$messaggio = "Spara f&ouml;r&auml;ndringar"; break;
case "Visualizza il documento":  		$messaggio = "Se dokument"; break;
case "Documento salvato":  			$messaggio = "Dokumentet sparat"; break;
case "Variabili":  				$messaggio = "Variabler"; break;
case "Aggiungi":  				$messaggio = "L&auml;gg till"; break;
case "Cambia":  				$messaggio = "&Auml;ndra"; break;
case "Formato del documento":  			$messaggio = "Dokumentformat"; break;
case "EMAIL":  					$messaggio = "E-POST"; break;
case "Oggetto":  				$messaggio = "&Auml;mne"; break;
case "Formato del documento cambiato":  	$messaggio = "Dokumentformat &auml;ndrat"; break;
case "Oggetto cambiato":  			$messaggio = "&Auml;mne &auml;ndrat"; break;
case "Allegato":  				$messaggio = "Bilaga"; break;
case "Elimina":  				$messaggio = "Ta bort"; break;
case "Mandare una copia bcc":  			$messaggio = "S&auml;nd en hemlig kopia"; break;
case "al mittente":  				$messaggio = "till avs&auml;ndaren"; break;
case "all'indirizzo":  				$messaggio = "till adressen"; break;
case "Allegato salvato":  			$messaggio = "Bilaga sparad"; break;
case "Allegato eliminato":  			$messaggio = "Bilaga borttagen"; break;
case "Copie bcc da spedire cambiate":  		$messaggio = "Hemliga kopior &auml;ndrade"; break;
case "SOSTITUISCI CON PARTE DA RIPETERE PER OGNI PRENOTAZIONE":	$messaggio = "ERS&Auml;TT MED DELEN SOM SKA UPPREPAS F&Ouml;R VARJE BOKNING"; break;
case "SOSTITUISCI CON LISTA OSPITI IN PRENOTAZIONE":	$messaggio = "ERS&Auml;TT MED EN LISTA &Ouml;VER BOKNINGSG&Auml;STER"; break;
case "SOSTITUISCI CON LISTA COSTI IN PRENOTAZIONE":	$messaggio = "ERS&Auml;TT MED EN LISTA &Ouml;VER BOKNINGSKOSTNADER"; break;
case "Salva i documenti con numero progressivo nella cartella":	$messaggio = "Spara dokument med progressiva nummer i mappen"; break;
case "I documenti non verranno salvati":	$messaggio = "Dokumenten kommer inte sparas"; break;
case "I documenti verranno salvati nella cartella":	$messaggio = "Dokumenten kommer sparas i mappen"; break;
case "SOSTITUISCI CON PARTE DA RIPETERE PER OGNI VALORE DELL'ARRAY":	$messaggio = "ERS&Auml;TT MED DEL SOM SKA UPPREPAS F&Ouml;R VARJE ARRAY-V&Auml;RDE"; break;
case "OPPURE":  				$messaggio = "OR"; break;
case "in":  					$messaggio = "in"; break;
case "documento":  				$messaggio = "document"; break;
case "Limiti":  				$messaggio = "Limits of"; break;
case "ripetizione prenotazioni":  		$messaggio = "reservations repetition"; break;
case "ripetizione ospiti":  			$messaggio = "guests repetition"; break;
case "ripetizione costi aggiuntivi":  		$messaggio = "extra costs repetition"; break;
case "ripetizione array":  			$messaggio = "array repetition"; break;
case "Errore nelle ripetizioni e condizioni annidate":	$messaggio = "Error in nested loops and conditions"; break;
case "parte sotto condizione":  		$messaggio = "part under condition"; break;
case "nome_variabile":  			$messaggio = "variable_name"; break;
case "valore":  				$messaggio = "value"; break;
case "SOSTITUISCI CON PARTE DA MOSTRARE SOLO SE E' SODDISFATTA LA CONDIZIONE PRECEDENTE":	$messaggio = "REPLACE WITH PART TO BE SHOWN ONLY IF PREVIOUS CONDITION IS SATISFIED"; break;
case "Variabili personalizzate e condizioni del documento":	$messaggio = "Custom variables and conditions of document"; break;
case "Condividi il numero progressivo con":  	$messaggio = "Share progressive number with"; break;
case "il documento":  				$messaggio = "document"; break;
case "Usa come nome del file":  		$messaggio = "Use as file name"; break;
case "il nome del documento":  			$messaggio = "the document name"; break;
case "un altro nome":  				$messaggio = "another name"; break;
case "non condividerà il numero progressivo con nessun documento":	$messaggio = "will not share progressive number with any document"; break;
case "condividerà il numero progressivo con il documento":	$messaggio = "will share progressive number with document"; break;
case "I file verranno salvati con il nome del documento":	$messaggio = "Files will be saved with the document name"; break;
case "I file verranno salvati con il nome":  	$messaggio = "Files will be saved with name"; break;
case "Salva automaticamente il documento":  	$messaggio = "Save the document automatically"; break;
case "mai":  					$messaggio = "never"; break;
case "alla registrazione dell'entrata":  	$messaggio = "at check-in"; break;
case "alla registrazione dell'uscita":  	$messaggio = "at check-out"; break;
case "Il documento verrà salvato automaticamente":	$messaggio = "The document will be saved automatically"; break;
case "Il documento non verrà salvato automaticamente":	$messaggio = "The document will not be saved automatically"; break;
case "multi-lingua":  				$messaggio = "multi-language"; break;
case "Avviso":  				$messaggio = "Warning"; break;
case "nei documenti in formato multi-lingua non è possibile ripetere una sola parte con i tag [r] e [/r], il documento viene ripetuto interamente per ogni prenotazione":	$messaggio = "with multi-language format it's not possible to repeat only one part under the tags [r] and [/r], the document is repeated entirely for each reservation"; break;
case "predefinito":  				$messaggio = "default"; break;
case "fai predefinito":  			$messaggio = "make default"; break;
case "Comprimi i file":  			$messaggio = "Compress files"; break;
case "Il documento non verrà salvato compresso su disco":	$messaggio = "The document will not be saved compressed on disk"; break;
case "Il documento verrà salvato compresso su disco":	$messaggio = "The document will be saved compressed on disk"; break;
case "Formato dell'email":  			$messaggio = "Email format"; break;
case "testo semplice":  			$messaggio = "plain text"; break;
case "html":  					$messaggio = "html"; break;
case "Formato dell'email cambiato":  		$messaggio = "Email format changed"; break;
case "ripetizione pagamenti":  			$messaggio = "payments repetition"; break;
case "ripetizione unità":  			$messaggio = "units repetition"; break;
case "SOSTITUISCI CON LISTA PAGAMENTI":  	$messaggio = "REPLACE WITH LIST OF PAYMENTS"; break;
case "Intestazione html personalizzata":  	$messaggio = "Custom html head"; break;
case "Modifica l'intestazione html":  		$messaggio = "Modify html head"; break;
case "Modifica la chiusura html":  		$messaggio = "Modify html foot"; break;
case "Intestazione html cambiata":  		$messaggio = "Html head changed"; break;
case "Chiusura html cambiata":  		$messaggio = "Html foot changed"; break;
case "Incrementa il numero progressivo ad ogni sua apparizione":	$messaggio = "Increase the progressive number each time that it appears"; break;
case "Ogni documento avrà un unico numero progressivo":	$messaggio = "Each document will have a unique progressive number"; break;
case "Il numero progressivo verrà incrementato ogni volta che compare nel documento":	$messaggio = "The progressive number will be increased each time it appears in the document"; break;
case "Estensione con cui vedere e scaricare il documento":	$messaggio = "Extension for viewing and downloading the document"; break;
case "predefinita":  				$messaggio = "default"; break;
case "personalizzata":  			$messaggio = "custom"; break;
case "Estensione cambiata":  			$messaggio = "Extension changed"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-sv_2.2.3-1.tar.gz: sv/modifica_contratto.php <==
<?php

switch ($messaggio) {

case "Torna indietro":  			$messaggio = "Bak&aring;t"; break;
case "Modifica il documento":  			$messaggio = "&Auml;ndra dokument"; break;
case "Salva le modifiche":  			$messaggio = "Spara f&ouml;r&auml;ndringar"; break;
case "Visualizza il documento":  		$messaggio = "Se dokument"; break;
case "Documento salvato":  			$messaggio = "Dokumentet sparat"; break;
case "Variabili":  				$messaggio = "Variabler"; break;
case "Aggiungi":  				$messaggio = "L&auml;gg till"; break;
case "Cambia":  				$messaggio = "&Auml;ndra"; break;
case "Formato del documento":  			$messaggio = "Dokumentformat"; break;
case "EMAIL":  					$messaggio = "E-POST"; break;
case "Oggetto":  				$messaggio = "&Auml;mne"; break;
case "Formato del documento cambiato":  	$messaggio = "Dokumentformat &auml;ndrat"; break;
case "Oggetto cambiato":  			$messaggio = "&Auml;mne &auml;ndrat"; break;
case "Allegato":  				$messaggio = "Bilaga"; break;
case "Elimina":  				$messaggio = "Ta bort"; break;
case "Mandare una copia bcc":  			$messaggio = "S&auml;nd en hemlig kopia"; break;
case "al mittente":  				$messaggio = "till avs&auml;ndaren"; break;
case "all'indirizzo":  				$messaggio = "till adressen"; break;
case "Allegato salvato":  			$messaggio = "Bilaga sparad"; break;
case "Allegato eliminato":  			$messaggio = "Bilaga borttagen"; break;
case "Copie bcc da spedire cambiate":  		$messaggio = "Hemliga kopior &auml;ndrade"; break;
case "SOSTITUISCI CON PARTE DA RIPETERE PER OGNI PRENOTAZIONE":	$messaggio = "ERS&Auml;TT MED DELEN SOM SKA UPPREPAS F&Ouml;R VARJE BOKNING"; break;
case "SOSTITUISCI CON LISTA OSPITI IN PRENOTAZIONE":	$messaggio = "ERS&Auml;TT MED EN LISTA &Ouml;VER BOKNINGSG&Auml;STER"; break;
case "SOSTITUISCI CON LISTA COSTI IN PRENOTAZIONE":	$messaggio = "ERS&Auml;TT MED EN LISTA &Ouml;VER BOKNINGSKOSTNADER"; break;
case "Salva i documenti con numero progressivo nella cartella":	$messaggio = "Spara dokument med progressiva nummer i mappen"; break;
case "I documenti non verranno salvati":	$messaggio = "Dokumenten kommer inte sparas"; break;
case "I documenti verranno salvati nella cartella":	$messaggio = "Dokumenten kommer sparas i mappen"; break;
case "SOSTITUISCI CON PARTE DA RIPETERE PER OGNI VALORE DELL'ARRAY":	$messaggio = "ERS&Auml;TT MED DEL SOM SKA UPPREPAS F&Ouml;R VARJE ARRAY-V&Auml;RDE"; break;
case "OPPURE":  				$messaggio = "OR"; break;
case "in":  					$messaggio = "in"; break;
case "al":  					$messaggio = "to"; break;
case "e":  					$messaggio = "and"; break;
case "documento":  				$messaggio = "document"; break;
case "Limiti":  				$messaggio = "Limits of"; break;
case "ripetizione prenotazioni":  		$messaggio = "reservations repetition"; break;
case "ripetizione ospiti":  			$messaggio = "guests repetition"; break;
case "ripetizione costi aggiuntivi":  		$messaggio = "extra costs repetition"; break;
case "ripetizione array":  			$messaggio = "array repetition"; break;
case "Errore nelle ripetizioni e condizioni annidate":	$messaggio = "Error in nested loops and conditions"; break;
case "parte sotto condizione":  		$messaggio = "part under condition"; break;
case "nome_variabile":  			$messaggio = "variable_name"; break;
case "valore":  				$messaggio = "value"; break;
case "SOSTITUISCI CON PARTE DA MOSTRARE SOLO SE E' SODDISFATTA LA CONDIZIONE PRECEDENTE":	$messaggio = "REPLACE WITH PART TO BE SHOWN ONLY IF PREVIOUS CONDITION IS SATISFIED"; break;
case "Variabili personalizzate e condizioni del documento":	$messaggio = "Custom variables and conditions of document"; break;
case "Condividi il numero progressivo con":  	$messaggio = "Share progressive number with"; break;
case "il documento":  				$messaggio = "document"; break;
case "Usa come nome del file":  		$messaggio = "Use as file name"; break;
case "il nome del documento":  			$messaggio = "the document name"; break;
case "un altro nome":  				$messaggio = "another name"; break;
case "non condividerà il numero progressivo con nessun documento":	$messaggio = "will not share progressive number with any document"; break;
case "condividerà il numero progressivo con il documento":	$messaggio = "will share progressive number with document"; break;
case "I file verranno salvati con il nome del documento":	$messaggio = "Files will be saved with the document name"; break;
case "I file verranno salvati con il nome":  	$messaggio = "Files will be saved with name"; break;
case "Salva automaticamente il documento":  	$messaggio = "Save the document automatically"; break;
case "mai":  					$messaggio = "never"; break;
case "alla registrazione dell'entrata":  	$messaggio = "at check-in"; break;
case "alla registrazione dell'uscita":  	$messaggio = "at check-out"; break;
case "Il documento verrà salvato automaticamente":	$messaggio = "The document will be saved automatically"; break;
case "Il documento non verrà salvato automaticamente":	$messaggio = "The document will not be saved automatically"; break;
case "multi-lingua":  				$messaggio = "multi-language"; break;
case "Avviso":  				$messaggio = "Warning"; break;
case "nei documenti in formato multi-lingua non è possibile ripetere una sola parte con i tag [r] e [/r], il documento viene ripetuto interamente per ogni prenotazione":	$messaggio = "with multi-language format it's not possible to repeat only one part under the tags [r] and [/r], the document is repeated entirely for each reservation"; break;
case "predefinito":  				$messaggio = "default"; break;
case "fai predefinito":  			$messaggio = "make default"; break;
case "Comprimi i file":  			$messaggio = "Compress files"; break;
case "Il documento non verrà salvato compresso su disco":	$messaggio = "The document will not be saved compressed on disk"; break;
case "Il documento verrà salvato compresso su disco":	$messaggio = "The document will be saved compressed on disk"; break;
case "Formato dell'email":  			$messaggio = "Email format"; break;
case "testo semplice":  			$messaggio = "plain text"; break;
case "html":  					$messaggio = "html"; break;
case "Formato dell'email cambiato":  		$messaggio = "Email format changed"; break;
case "ripetizione pagamenti":  			$messaggio = "payments repetition"; break;
case "ripetizione unità":  			$messaggio = "units repetition"; break;
case "SOSTITUISCI CON LISTA PAGAMENTI":  	$messaggio = "REPLACE WITH LIST OF PAYMENTS"; break;
case "Intestazione html personalizzata":  	$messaggio = "Custom html head"; break;
case "Modifica l'intestazione html":  		$messaggio = "Modify html head"; break;
case "Modifica la chiusura html":  		$messaggio = "Modify html foot"; break;
case "Intestazione html cambiata":  		$messaggio = "Html head changed"; break;
case "Chiusura html cambiata":  		$messaggio = "Html foot changed"; break;
case "Incrementa il numero progressivo ad ogni sua apparizione":	$messaggio = "Increase the progressive number each time that it appears"; break;
case "Ogni documento avrà un unico numero progressivo":	$messaggio = "Each document will have a unique progressive number"; break;
case "Il numero progressivo verrà incrementato ogni volta che compare nel documento":	$messaggio = "The progressive number will be increased each time it appears in the document"; break;
case "Estensione con cui vedere e scaricare il documento":	$messaggio = "Extension for viewing and downloading the document"; break;
case "predefinita":  				$messaggio = "default"; break;
case "personalizzata":  			$messaggio = "custom"; break;
case "Estensione cambiata":  			$messaggio = "Extension changed"; break;
case "Considera questo documento come una API":	$messaggio = "Consider this document as an API"; break;
case "Il documento verrà considerato come una API":	$messaggio = "The document will be considered as an API"; break;
case "Il documento non verrà più considerato come una API":	$messaggio = "The document will no longer be considered as an API"; break;
case "Password":  				$messaggio = "Password"; break;
case "La password per la API del documento è stata cambiata":	$messaggio = "The password for document API has been changed"; break;
case "Esempi di URL per chiamare il documento":	$messaggio = "Examples of URLs to call the document"; break;
case "Tutte le prenotazioni dell'anno":  	$messaggio = "All reservations from year"; break;
case "Mostra il documento come visto dall'utente":	$messaggio = "Show the document as seen by user"; break;
case "L'utente per la API del documento è stato cambiato":	$messaggio = "The user for docuemnt API has been changed"; break;
case "Nota":  					$messaggio = "Notice"; break;
case "se la variabile":  			$messaggio = "if the variable"; break;
case "non è presente nella URL allora verranno usate le prenotazioni dell'anno corrente":	$messaggio = "is not present in the URL then reservations from current year will be used"; break;
case "Tutte le prenotazioni presenti dal":  	$messaggio = "All the reservations present from"; break;
case "si possono usare anche le parole":  	$messaggio = "you can also use the words"; break;
case "come date":  				$messaggio = "as dates"; break;
case "Tutte le prenotazioni con numero dal":  	$messaggio = "All the reservations with numbers from"; break;
case "Altri esempi dell'uso della variabile":  	$messaggio = "Other examples of the use of variable"; break;
case "Tutte le prenotazioni inserite dal":  	$messaggio = "All reservations inserted from"; break;
case "Tutti gli arrivi del":  			$messaggio = "All arrivals on"; break;
case "Tutti le partenze del":  			$messaggio = "All departures on"; break;
case "Tutti i clienti":  			$messaggio = "All the clients"; break;
case "escludendo gli ospiti":  			$messaggio = "excluding guests"; break;
case "inclusi gli ospiti":  			$messaggio = "including guests"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
